/*
 * The MIT License (MIT)
 * 
 * Copyright (c) 2015 Camil Staps <info@camilstaps.nl>
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.camilstaps.mandelbrot;

import java.awt.BorderLayout;
import java.awt.Dimension;
import javax.swing.JFrame;

/**
 * Solutions to week 15
 * @author Camil Staps
 */
public class MandelbrotWindow extends JFrame {
    
    /**
     * Create a window with a grid, progress bar and textfields
     */
    private MandelbrotWindow() {
        super("Mandelbrot");
        
        FractalModel fm = new FractalModel();
        
        setLayout(new BorderLayout());
        
        setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        setLocationRelativeTo(null);
        setVisible(true);
        
        Grid grid = new Grid(fm);
        Textfields textfields = new Textfields(fm, grid);
        
        add(grid, BorderLayout.CENTER);
        add(grid.getProgressView(), BorderLayout.SOUTH);
        add(textfields, BorderLayout.EAST);
        
        getContentPane().setPreferredSize(new Dimension(
                grid.getWidth() + textfields.getWidth(), 
                Math.max(grid.getHeight(), textfields.getHeight()) + grid.getProgressView().getHeight()
        ));
        pack();
        setResizable(false);
    }
    
    public static void main(String[] args) {
        MandelbrotWindow mw = new MandelbrotWindow();
    }
    
}
